#!/bin/bash
#
#    Copyright (c) 2004-2019 Brocade Communications Systems LLC.
#    All rights reserved.
#
#    Description:
#	The dft_post script is invoked after dumping DFT shared memory
#	features to display any additional features that were skipped
#	in shared memory.

STS_OK=0
STS_ERR=255

# Trap / Ignore SIGINT so user cannot interrupt this script with ^C
trap "" 2
trap "" SIGPIPE

ENABLE_FEATURE=1
FLAG=$1
INDEX=$2 # Index will be the last index after dft --show from CLI.

if [ $# -eq 3 ]; then
	REST_FLAG=$3
else
	REST_FLAG=""
fi

DFT_POST_EXT_FILE="/tmp/dft_post_ext.txt"

#Empty the DFT EXT FILE
printf "" > $DFT_POST_EXT_FILE

DFT_PRINT() {
	if [ $# -eq 2 ] && [ "$2" == "$ENABLE_FEATURE" ]; then
		/fabos/cliexec/dft --post -fid "$1" -enable -flag $FLAG -index $INDEX $REST_FLAG
		if [ $? -ne 0 ]; then
			exit $STS_ERR
		fi
	elif [ $# -eq 2 ] && [ ! -z "$2" ]; then
		/fabos/cliexec/dft --post -fid "$1" -text "$2" -flag $FLAG -index $INDEX $REST_FLAG
		if [ $? -ne 0 ]; then
			exit $STS_ERR
		fi
	elif [ $# -eq 3 ]; then
		if [ "$2" == "$ENABLE_FEATURE" ]; then
			/fabos/cliexec/dft --post -fid "$1" -enable -text "$3" -flag $FLAG -index $INDEX $REST_FLAG
			if [ $? -ne 0 ]; then
				exit $STS_ERR
			fi
		elif [ "$3" == "$ENABLE_FEATURE" ]; then
			/fabos/cliexec/dft --post -fid "$1" -enable -text "$2" -flag $FLAG -index $INDEX $REST_FLAG
			if [ $? -ne 0 ]; then
				exit $STS_ERR
			fi
		fi
	elif [ $# -eq 1 ]; then
		/fabos/cliexec/dft --post -fid "$1" -flag $FLAG -index $INDEX $REST_FLAG
		if [ $? -ne 0 ]; then
			exit $STS_ERR
		fi
	elif [ $# -lt 1 -o $# -gt 3 ]; then
		exit $STS_ERR
	fi
	(( INDEX++ ))
}

DFT_PRINT_CLI () {
	$@ -index $INDEX -flag $FLAG >> "$DFT_POST_EXT_FILE"
	if [ $? -ne 0 ]; then
		exit $STS_ERR
	fi
}

#########################
#       main()          #
#########################

######################### DETAILS OF DFT_POST SCRIPT ##########################
# 1. Features can be updated in DFT_POST in 2 ways. By using DFT_PRINT and    #
# DFT_PRINT_CLI. For both ways, the feature has to be defined as Skip=1 in    #
# XML									      #
# 2. DFT PRINT used to print a skipped feature and update its status or free  #
# text. Syntax defined below.						      #
# 3. DFT_PRINT_CLI used to execute an external CLI to print feature details.  #
# The features printed as part of DFT_PRINT_CLI needs to be aligned with      #
# the same format as dft --show format. All fields should not exceed their    #
# max lengths defined in XML. Along with the CLI called with DFT_PRINT_CLI,   #
# the flag used for dft --show will also be passed with -flag <> and	      #
# -index <>. The flag can be show / default / hidden / obsolete / all /	      #
# enabled / disabled. The index will be the index that needs to be printed    #
# along with the next feature in dft --show O/P. This index needs to be	      #
# manually incremented in the script with the number of features printed in   #
###############################################################################


######################### Instructions for DFT_PRINT ##########################
# DFT_PRINT "base_id-feature_id" [$ENABLE_FEATURE] ["Free Text"]              #
# Base id: Base ID defined in XML.                                            #
# feature id: feature ID of the feature defined in XML .                      #
# state: Current state of feature can be enabled but not disabled.            #
#        Default state can only be updated in XML. Features enabled by        #
#        default cannot be disabled.                                          #
# data: Free data. This is optional. Max length = 32 characters.              #
###############################################################################


