#!/bin/bash
#
#    Copyright (c) 2004-2019 Brocade Communications Systems LLC.
#    All rights reserved.
#
#    Description:
#	The dft_pre script is invoked before a dft --show to update
#	feature details in DFT shared memory.

dft_log_file=/tmp/dft_log_file
STS_OK=0
STS_ERR=255

DEBUG=1
if [ "$DEBUG" = 1 ]; then
	ECHO='echo -e'
else
	ECHO=:
fi

export LOGIN_ID=root
export ROLE_ID=root
export CHASSIS_ROLEID=0
export FABOS_SWITCHNO=-1

if [ -f "$dft_log_file" ]
then
	/bin/rm -f "$dft_log_file"
fi
# Trap / Ignore SIGINT so user cannot interrupt this script with ^C
trap "" 2
trap "" SIGPIPE

ENABLE_FEATURE=1
DEFALUT_DISABLE=0
DEFAULT_ENABLE=1

flag=$1

# DFT_UPDATE "base_id-feature_id" [$ENABLE_FEATURE] ["Free Text"]
# Instructions for DFT_UPDATE below in main() section.
DFT_UPDATE() {
        if [ $# -eq 2 ] && [ "$2" == "$ENABLE_FEATURE" ]; then
		/fabos/cliexec/dft --update -fid "$1" -enable
		if [ $? -ne 0 ]; then
			exit $STS_ERR
		fi
	elif [ $# -eq 2 ] && [ ! -z "$2" ]; then
		/fabos/cliexec/dft --update -fid "$1" -text "$2"
		if [ $? -ne 0 ]; then
			exit $STS_ERR
		fi
	elif [ $# -eq 3 ]; then
		if [ "$2" == "$ENABLE_FEATURE" ] ; then
			/fabos/cliexec/dft --update -fid "$1" -enable -text "$3"
			if [ $? -ne 0 ]; then
				exit $STS_ERR
			fi
		elif [ "$3" == "$ENABLE_FEATURE" ] ; then
		    
			/fabos/cliexec/dft --update -fid "$1" -enable -text "$2"
			if [ $? -ne 0 ]; then
				exit $STS_ERR
			fi
		fi
	elif [ $# -lt 2 -o $# -gt 3 ]; then
		exit $STS_ERR
	fi
}

#DFT_DEFAULT_UPDATE "base_id-feature_id" "default_state"
#default_state : Default state of feature which is to update in the DFT shm.
#				All features default state is added in XML file.
#				In some cases if the user wanted to upate the default state,
# 				will use this function.
#				state value can be either DEFAULT_ENABLE or  DEFALUT_DISABLE .
# 

DFT_DEFAULT_UPDATE() {
	if [ $# -eq 2 ] && [ "$2" == "$DEFAULT_ENABLE" -o "$2" == "$DEFALUT_DISABLE" ]; then
		/fabos/cliexec/dft --update -fid "$1" -default -state "$2"
		if [ $? -ne 0 ]; then
			exit $STS_ERR
		fi
	elif [ $# -lt 2 -o $# -gt 3 ]; then
		exit $STS_ERR
	fi
}


#########################
#	main()		#
#########################

####################### Instructions for DFT_UPDATE() #######################
# DFT_UPDATE "base_id-feature_id" [$ENABLE_FEATURE] ["Free Text"]	    #
# Base id: Base ID defined in XML.	                                    #
# feature id: feature ID of the feature defined in XML .                    #
# state: Current state of feature can be enabled but not disabled.          #
#        Default state can only be updated in XML. Features enabled by      #
#        default cannot be disabled.                                        #
# data: Free data. This is optional. Max length = 32 characters.            #
#############################################################################

HASHOW="$(/fabos/bin/hashow)"
hashow_cmd=$(/bin/ls /fabos/cliexec/hashow)
if [ "$hashow_cmd" != "/fabos/cliexec/hashow" ]; then
       	hashow_cmd="/fabos/bin/hashow"
fi

ha_role() {
 	case "$($hashow_cmd | ( read a; echo $a ))" in
	    *Local*Active*)
	    printf "ACTIVE"
 	    ;;
	    *Local*Standby*)
	    printf "STANDBY"
 	    ;;
	    *"Not supported"*)
	    printf "ACTIVE"
 	    ;;
	    *)
	    printf "STANDBY"
	    ;;
	esac
}

#
# swbd
#
# Retrieve the current system platform name, of the form "SWBDn", where n
# is cardinal number, assuming a sin/hinv input stream.
#
swbd() {
	sed -n -e 's/^.\+\(SWBD[[:digit:]]\{1,\}\).\+$/\1/gp'
}

NULL=/dev/null
# Determine the system platform identifier.
SWBD=`/sbin/sin | swbd 2> ${NULL}`

is_gen7() {
	case ${SWBD##SWBD} in
	'174' | '179' | '180' | '181' | '186' | '189' | '191')
		return 1
		;;
	esac

	return 0
}

HA_ROLE=$(ha_role)
if [ $HA_ROLE == "ACTIVE" ]; then
    ACTIVECP=1
fi
if /fabos/bin/fosconfig --show | grep "Virtual Fabric" | grep enabled > /dev/null 2>&1 ; then
	VF_ENABLED=1;
else 
	VF_ENABLED=0;
fi


maps_feature_update() {
     feature_id=$1
     feature_name=$2
     enabled_or_disabled=$3

     #str="$feature_name is enabled"
     if [ ! -z "$enabled_or_disabled" ]
     then
	#ret=`DFT_UPDATE "$fid" $ENABLE_FEATURE "$str"`
	ret=`DFT_UPDATE "$fid" $ENABLE_FEATURE`
	$ECHO "$feature_id,$feature_name enabled;return:$ret " >> $dft_log_file		
	
	#$ECHO "DFT Infra failed for $feature_id,$feature_name, ret:$ret" >> $dft_log_file 
     else
	$ECHO "$feature_id,$feature_name is not enabled" >> $dft_log_file
     fi

}

maps_feature_update_default() {
     feature_id=$1
     feature_name=$2
     enabled_or_disabled=$3

     if [ ! -z "$enabled_or_disabled" ]
     then
		ret=`DFT_DEFAULT_UPDATE "$fid" $ENABLE_FEATURE`
		$ECHO "$feature_id,$feature_name enabled;return:$ret " >> $dft_log_file
     else
		$ECHO "$feature_id,$feature_name is not enabled" >> $dft_log_file
     fi
}
    
#############################
# Manages the MAPS features for DFT
#
# It is based on the configuration and if need be we can use our internal
# command to fetch the data. Simple rule to define the DFT feature - if it is 
# enabled in any logical switch then it means it is enabled in the chassis.
# The reason of this decision is because DFT is chassis wide feature and had no
# knowledge of logical switch.
#
# Open items - stats is not supported in this feature. Two reasons:
#	a) space is not sufficient
#	b) format is not fixed to capture the stats		
############################

manage_maps_features() {

     config_file="/tmp/config_all" 
    /fabos/cliexec/configshow -all | grep -v 'Warn' > "$config_file"

    #checking the dynamic group list. NULL or not NULL have one conclusion - used.
    dyn=`/bin/cat "$config_file"|grep maps.dyngrp.list`
    $ECHO "Dynamic group: $dyn" >> $dft_log_file    

    #checking the circuit custom group, magic 4 means circuit type.
    circuit=`/bin/cat "$config_file"|grep maps.udgroup|grep ':4'`
    $ECHO "Circuit group: $circuit" >> $dft_log_file    

    #checking the augmentation of the pre defined groups.
    aug=`/bin/cat "$config_file"|grep maps.group.augment.`
    $ECHO "Group augmentation: $aug" >> $dft_log_file    

    #checking rule on rule 
    ror=`/bin/cat "$config_file"|grep ruleType=1`
    $ECHO "Rule on rule: $ror" >> $dft_log_file    

    # decom flavor
    #checking decom flavor
    decom_behavior=`/bin/cat "$config_file"|grep 'maps.config.decom_no_disable:'`
    
    decom_impair=''
    decom_with_disable=''
    if [ ! -z "$decom_behavior" ]
    then
	impair=`echo $decom_behavior | gawk -F: '{print $2}'`
	if [ $impair -eq 1 ]
	then
		decom_impair='impair'
	else
		decom_with_disable='with disable'
	fi
    fi

    # FPI profiles
    # checks the fpi profiles in any of the logical switch
    fpi_profiles=`/bin/cat "$config_file"|grep maps.fpi`
    $ECHO "FPI profiles: $fpi_profiles" >> $dft_log_file    

    # Global QT
    # checks the global qt feature of MAPS
    global_qt=`/bin/cat "$config_file"|grep maps.config.quietTime:`
    $ECHO "Global QT: $global_qt" >> $dft_log_file    

    # Local QT
    # checks the local qt feature of MAPS
    local_qt=`/bin/cat "$config_file"|grep "maps.rule."|grep "qt="`
    $ECHO "Local QT: $local_qt" >> $dft_log_file

    # fence, decom, fpin,  actions, sddq, unquar
    # checks the global MAPS actions	
    #fpin_act=0 
    #decom_act=0
    #fence_act=0
    #unquar_act=0
    #sddq_act=0

    maps_actions=`/bin/cat "$config_file"|grep "maps.actions:"`
    for act in $maps_actions
    do
    	act_bitmaps=`echo $act | gawk -F: '{print $2}'`
	#echo "bitmap $act_bitmaps"
	act=$(($act_bitmaps&0x200000))
	if [ $act -ne 0 ]
	then
		fpin_act=$act
	fi
	act=$(($act_bitmaps&0x08))
	if [ $act -ne 0 ]
	then
		fence_act=$act
	fi
	act=$(($act_bitmaps&0x0800))
	if [ $act -ne 0 ]
	then
		decom_act=$act
	fi
	act=$(($act_bitmaps&0x010000))
	if [ $act -ne 0 ]
	then
		sddq_act=$act
	fi
	act=$(($act_bitmaps&0x040000))
	if [ $act -ne 0 ]
	then
		unquar_act=$act
	fi
    done

    $ECHO "maps_actions: $maps_actions fpin_act: $fpin_act fence_act: $fence_act decom_act: $decom_act" >> $dft_log_file
    $ECHO "maps_actions: $maps_actions sddq_act: $sddq_act unquar_act: $unquar_act" >> $dft_log_file

    # Pause and Continue feature
    # Checks the pause and continue feature and enable the status 
    pause_n_restart=`/bin/cat "$config_file"|grep "maps.group.pauselist."`
    $ECHO "pause and restart: $pause_n_restart" >> $dft_log_file

    # custom policies
    # checked the custom policies and if it exist then we need to
    # turn on the status of the feature
    custom_policies=`/bin/cat "$config_file"|grep "maps.policy.list:"`
    $ECHO "custom policies: $custom_policies" >> $dft_log_file

    # custom rules
    # checked the custom rules and if it exist then we need to
    # turn on the status of the feature    
    custom_rules=`/bin/cat "$config_file"|grep "maps.rules.list:"`
    $ECHO "custom rules: $custom_rules" >> $dft_log_file

    ############################################################
    # Logging of the features started 
    ###########################################################
	
    fid="117-001"
    feature_name='Circuit group'
    maps_feature_update "$fid" "$feature_name" "$circuit"

    fid="117-002"
    feature_name="Rule on rule"
    maps_feature_update "$fid" "$feature_name" "$ror"

    fid="117-003"
    feature_name="Decom with impair"
	# in Gen7 platforms, by default enable decom with imapir feature
	is_gen7
	if [ $? -eq 1 ]; then
		maps_feature_update_default "$fid" "$feature_name" "$DEFAULT_ENABLE"
	fi
    maps_feature_update "$fid" "$feature_name" "$decom_impair"

    fid="117-004"
    feature_name="Decom with disable"
	# in Gen6 platforms, by default enable decom with disable feature
	is_gen7
	if [ $? -eq 0 ]; then
		maps_feature_update_default "$fid" "$feature_name" "$DEFAULT_ENABLE"
	fi
    maps_feature_update "$fid" "$feature_name" "$decom_with_disable"

    fid="117-005"
    feature_name="Group augmentation"
    maps_feature_update "$fid" "$feature_name" "$aug"

    fid="117-006"
    feature_name="Dynamic"
    maps_feature_update "$fid" "$feature_name" "$dyn"

    fid="117-007"
    feature_name='FPI prpfiles'
    maps_feature_update "$fid" "$feature_name" "$fpi_profiles"

    fid="117-008"
    feature_name='Global QT'
	# global QT feature is enabled by default in Vepser
	if [ ${SWBD##SWBD} -eq 189 ]; then
		maps_feature_update_default "$fid" "$feature_name" "$DEFAULT_ENABLE"
	fi
    maps_feature_update "$fid" "$feature_name" "$global_qt"

    fid="117-009"
    feature_name='Local QT'
    maps_feature_update "$fid" "$feature_name" "$local_qt"

    fid="117-010"
    feature_name='SDDQ action'
    maps_feature_update "$fid" "$feature_name" "$sddq_act"

    fid="117-011"
    feature_name='UNQUAR action'
    maps_feature_update "$fid" "$feature_name" "$unquar_act"

    fid="117-012"
    feature_name='Custom policies'
    maps_feature_update "$fid" "$feature_name" "$custom_policies"

    fid="117-013"
    feature_name='Custom rule'
    maps_feature_update "$fid" "$feature_name" "$custom_rules"

    fid="117-014"
    feature_name='Pause and Restart'
    maps_feature_update "$fid" "$feature_name" "$pause_n_restart"

    fid="117-015"
    feature_name='Fence action'
    maps_feature_update "$fid" "$feature_name" "$fence_act"

    fid="117-016"
    feature_name='Decom action'
    maps_feature_update "$fid" "$feature_name" "$decom_act"

    fid="117-017"
    feature_name='FPIN action'
    maps_feature_update "$fid" "$feature_name" "$fpin_act"	
}

if [ $ACTIVECP ]
then
	manage_maps_features

	fid="127-001"
	str="Supported only on Gen7 platforms"

	is_gen7
	if [ $? -eq 1 ]; then
		ret=`DFT_UPDATE "$fid" $ENABLE_FEATURE`
	else
		ret=`DFT_UPDATE "$fid" "$str"`
	fi

   fid="131-001"
   str="Keep alive feature enabled"

   keep=`/bin/cat /tmp/config_all|grep "http.keepalive.enabled" | /usr/bin/cut -d':' -f 2`
   if [[ $keep -eq 1 ]]; then
      ret=`DFT_UPDATE "$fid" $ENABLE_FEATURE`
   fi

   fid="103-001"
   str="USB feature enabled"

   usb_folder="/usb/usbstorage"
   if [[ -d "$usb_folder" ]]; then
      ret=`DFT_UPDATE "$fid" $ENABLE_FEATURE`
   fi

   fid="105-001"
   str="ASC feature enabled"

   asc=`/bin/cat /tmp/config_all|grep "http.sl.state" | /usr/bin/cut -d':' -f 2`
   if [[ $asc -eq 1 ]]; then
      ret=`DFT_UPDATE "$fid" $ENABLE_FEATURE`
   fi

   fid="134-001"
   str="SNMPV1 feature enabled"

   asc=`/bin/cat /tmp/config_all|grep "snmp.v1Enable:" | /usr/bin/cut -d':' -f 2`
   if [[ $asc -eq 1 ]]; then
      ret=`DFT_UPDATE "$fid" $ENABLE_FEATURE`
   fi

   fid="134-002"
   str="Informs feature enabled"

   asc=`/bin/cat /tmp/config_all|grep "snmp.inform" | /usr/bin/cut -d':' -f 2`
   if [[ $asc -eq 1 ]]; then
      ret=`DFT_UPDATE "$fid" $ENABLE_FEATURE`
   fi

   fid="134-003"
   str="Password Encryption feature enabled"

   asc=`/bin/cat /tmp/config_all|grep "snmp.usmUserPaswdEncFlag:" | /usr/bin/cut -d':' -f 2`
   if [[ $asc -eq 1 ]]; then
      ret=`DFT_UPDATE "$fid" $ENABLE_FEATURE`
   fi

   fid="134-004"
   str="Throttling feature enabled"

   asc=`/bin/cat /tmp/config_all|grep "snmp.throttle.flag" | /usr/bin/cut -d':' -f 2`
   if [[ $asc -eq 1 ]]; then
      ret=`DFT_UPDATE "$fid" $ENABLE_FEATURE`
   fi

   fid="101-002"
   str="Virtual Fabric enabled"

   if [[ $VF_ENABLED -eq 1 ]]; then
      ret=`DFT_UPDATE "$fid" $ENABLE_FEATURE`
   fi

   rd=$(rtedebug show dump dft > /dev/null)
fi

#
# Handle Switch and FC driver configuration based features.
# Usage handle_swch_fc_dft "configkey" "configkey_value_to_grep" "dft_feature_tag"
#

handle_swch_fc_dft()
{
	for str in `cat /etc/fabos/fabos.*.conf| grep $1 | /usr/bin/cut -d':' -f 2`
	do
		if [ "$str" != "$2" ];then
			ret=`DFT_UPDATE "$3" $ENABLE_FEATURE`
			echo "$3 enabled: $ret" >> $dft_log_file
		fi
	done
}

handle_swch_fc_dft "fabric.wwnPidMode" "0" "111-002"
handle_swch_fc_dft "switch.login.freeFdiscs" "0" "111-003"
handle_swch_fc_dft "switch.login.enforce_login" "0" "111-008"
handle_swch_fc_dft "portNpivLimit" "" "112-002"
handle_swch_fc_dft "switch.login.flogisPerSec" "0" "112-003"
handle_swch_fc_dft "switch.xisluse" "0" "112-005"


#
# Handle ASIC and Blade driver configuration based features.
# Usage handle_asic_bl_dft "configkey" "configkey_value_to_grep" "dft_feature_tag"
#


handle_asic_bl_dft()
{
        for str in `/fabos/cliexec/configshow -all | grep $1 | /usr/bin/cut -d':' -f 2`
        do
                if [ "$str" != "$2" ];then
                        ret=`DFT_UPDATE "$3" $ENABLE_FEATURE`
                        echo "$3 enabled: $ret" >> $dft_log_file
                fi
        done
}

handle_asic_bl_dft "system.Enable.bladeAutoRecovery" "0" "115-033"
handle_asic_bl_dft "system.blade.bladeFaultOnHwErrMsk" "0" "115-035"

exit $STS_OK
