#!/bin/sh
#
#    Copyright (c) 1996-2011 Brocade Communications Systems, Inc.
#    All rights reserved.
#
#    File name:   ssave_infra.sh.in
#    Module name: utils/support
#
#    This file expected to be invoked by supportsave infrastructure to 
#    collect FOS/NOS infrastructure
#    related data for switch post fiaure analysis
#
#
PATH=/bin:/usr/bin:/usr/sbin:/fabos/bin:/fabos/link_bin:

ssaveutil="/fabos/cliexec/ssave_util.sh"

#
#include ssave utility
#
if [ -e "$ssaveutil" ]
then
    . $ssaveutil
    rc=$?
    if [ $rc -ne 0 ]
    then
      echo "Error -- $ssaveutil err=$rc"
      exit 3
    fi
else
    echo "Error -- could not locate ssave common library $ssaveutil"
    exit 3
fi

parallel_ss_test="/var/log/ss_perf_log"
GZIP=/fabos/rbin/gzip

# *******************************************
# Collect cmsh data
# *******************************************
cmsh_cmd_exec()
{
    echo -e "*****************************************************************"
    echo -e "cmsh -e $@ :"
    echo -e "*****************************************************************"
    time /fabos/bin/cmsh -e "$@"
    echo -e "\n\n\n\n"
}

CMSHCMD=cmsh_cmd_exec

do_bladevershow() {
 # Do not run on standby CP.
 if [ "$STANDBY" = "TRUE" ]
 then
    return
 fi

 # If we are running on Saturn, get blade version for all AP blades.
 if [ $sw_platform == 42 ] || [ $sw_platform == 62 ] || [ $sw_platform == 77 ]
 then
    _cmd=`commandPath slotshow`
    ap1=`$_cmd | /bin/grep AP | wc -l`
    if [ $ap1 -gt 0 ]
    then
        for val in `$_cmd | /bin/grep AP | /bin/grep ENABLED | /usr/bin/cut -c1-5`
        do
            $CHASSISCMD bladevershow $val
        done
    /bin/echo ""
    fi
  else
    # Check if we are running on Sprint
    if [ $sw_platform = 46 ]  || [ $sw_platform = 95 ] || [ $sw_platform = 96 ] || [ $sw_platform = 97 ] || [ $sw_platform = 116 ] || [ $sw_platform = 107 ]
    then
       $CHASSISCMD bladevershow
    fi
  fi
}


# *******************************************
# Collect  FCIP blade port info supportsave data
# *******************************************
function get_fcip_port_info()
{
  if [ -d /proc/fabos/blade/0 ]
  then
      $ECHO "Mini-chassis system"
      
      $CHASSISCMD /bin/cat /proc/fabos/blade/0/info

      $CHASSISCMD /bin/cat /proc/fabos/blade/0/pt_prop
  else
      $ECHO "chassis"
      /fabos/link_bin/slotshow | grep "75" | cut -d ' ' -f3 >> /tmp/tmp_file
      for slot in `cat /tmp/tmp_file`
      do
	  $ECHO "slot-$slot-info :"
	  $CHASSISCMD /bin/cat /proc/fabos/blade/$slot/info
	  $EHCO "slot-$slot-pt_prop :"
	  $CHASSISCMD /bin/cat /proc/fabos/blade/$slot/pt_prop
      done
  fi
  if [ -f /tmp/tmp_file ]
  then
      rm -f /tmp/tmp_file
  else
      $ECHO "/tmp/tmp_file do not exit"
      $ECHO ""
  fi
}

unlink_files()
{

   $ECHO "List of the file being unlink, but still hold by process"
   #myarr=($(ls -l /proc/*/fd | awk '!/dev|pipe|socket|tmp|proc|total|anon/ {print $11}')) ; for i in "${myarr[@]}"; do if [ ! -f $i ]; then  echo $i; fi ;done

  pidarr=($(ps -ef | awk '!/PID/ {print $2}'))

  for pid in  "${pidarr[@]}"
  do
    farr=($(ls -l /proc/$pid/fd  2> /dev/null | awk '!/dev|pipe|socket|tmp|proc|total|anon/ {print $11}'))
    fsarr=($(ls -l /proc/$pid/fd  2> /dev/null | awk '!/dev|pipe|socket|tmp|proc|total|anon/ {print $12}'))
    for i in "${!farr[@]}"
    do
      if [ ! -f "${farr[i]}" ]
      then
	comm=`cat /proc/$pid/comm`
	#$ECHO -n "pid=$pid file=$i comm="; $CAT /proc/$pid/comm;
	printf 'pid=%s %s file=%s %s\n' "$pid" "$comm" "${farr[i]}" "${fsarr[i]}"
      fi
    done
  done
}


# *******************************************
# Collect pre supportsave data
# *******************************************
start_pre()
{
    system_info
#    set_lscfg_test
	if [ ! -e /fabos/link_sbin/lscfg_test ]; then
	  $ECHO "RAS start_pre creating symlink to lscfg_test"
	 /bin/ln -s /fabos/cliexec/lscfg_util /fabos/link_sbin/lscfg_test 2> /dev/null
	fi
    # ouput supportsave.conf
    $CATFILE /etc/fabos/supportsave-default.conf

    # previous supportsave log
    $CATFILE_RM /var/log/sslog.old

    $CATFILE_RM /var/log/ss_util_err.log.old
   
    # previous SS module CLI log /var/log/ssave.sh.log.old
    $CATFILE_RM /var/log/ssave.sh.log.old

    # output previous suportsave ftp debug logs
    $CATFILE_RM /var/log/ss_ftp_dbg_log

    # collect ras node info
    if [ "$STANDBY" = "FALSE" ]
    then
	# supportftp
	$CHASSISCMD supportftp
	if [ -e /usr/bin/errlogutest ]
	then
            /bin/rm /usr/bin/errlogutest
    	fi
	/bin/ln -s /fabos/cliexec/raslogt /usr/bin/errlogutest 2> /dev/null
	/usr/bin/errlogutest -a2
	$CATFILE_RM /tmp/errlogutestoutput.txt
	/bin/rm /usr/bin/errlogutest
    fi

    $CATFILE /proc/raslog/inq/hdr
    $CATFILE /proc/raslog/raslogd/hdr
    $CATFILE /proc/raslog/raslogd/msg
    $CATFILE /etc/raslog.conf

    # ouput console log
    if [ "$FABOS_OFF" = "FALSE" ]
    then
        $CATFILE /proc/consolelog | grep -Ev "Mail Recipient|Mail From Address|User name"
	if [ -f /var/log/prev_consolelog ]; then
		$CATFILE /var/log/prev_consolelog | grep -Ev "Mail Recipient|Mail From Address|User name"
	fi

	if [ -f /proc/dp0_consolelog ]; then
        $CHASSISCMD /sbin/bootenv dp_console
        $CATFILE  /proc/tty/driver/serial
	    $CATFILE /proc/dp0_consolelog
	fi

	if [ -f /proc/dp1_consolelog ]; then
	    $CATFILE /proc/dp1_consolelog
	fi

	$CATFILE /var/log/prev_dp0_consolelog
	$CATFILE /var/log/prev_dp1_consolelog

	$CHASSISCMD /fabos/cliexec/errdumpall

	#rasadmin Config
	$CHASSISCMD /fabos/sbin/rasadmin --show -disabled

	$CHASSISCMD /fabos/sbin/rasadmin --show -syslog
    fi

    $CATFILE /var/log/config_updown.log
    $CATFILE /var/log/config_show.log
    $CATFILE /var/log/config_library.log
    $CATFILE /var/log/config_library.log.save
    $CATFILE /mnt/var/log/config_library.log
    $CATFILE /mnt/var/log/config_library.log.save

    $CHASSISCMD /usr/bin/ipcs -m

    #output /proc/trace/ubuffers
    $CATFILE /proc/trace/ubuffers

    #output /proc/trace/kbuffers
    $CATFILE /proc/trace/kbuffers

    #output /proc/trace/tplist
    $CATFILE /proc/trace/tplist

    #Collect tracecfg
    $CATFILE /etc/fabos/trace.conf
    $CHASSISCMD /sbin/tracecfg -p

  # Collect tracecfg log file
    if [ -e "/var/log/tracecfg.log" ]
    then
	$CATFILE /var/log/tracecfg.log
    fi

    #Collect dropq message
    $CATFILE /proc/raslog/dropq/msg

    # Switch configuraton switch-conf.xx, vf-conf.xx
    $CATFILE /etc/fabos/config/vf-conf.$sw_platform

    $CATFILE /etc/fabos/config/switch-conf.$sw_platform

    $CATFILE /etc/fabos/config/vf-conf.$sw_platform.save

    $CATFILE /etc/fabos/config/switch-conf.$sw_platform.save

    $CATFILE /etc/fabos/config/vf-conf-new.$sw_platform

    $CATFILE /etc/fabos/config/vf-conf-new.$sw_platform.save

    # Default switch configuration switch-conf, vf-conf, system-conf
    $CATFILE /etc/fabos/config/vf-conf

    $CATFILE /etc/fabos/config/system-conf

    $CATFILE /etc/fabos/config/switch-conf

    # syslock dump
    if [ -f /proc/syslock/status ]; then
	$CHASSISCMD  /bin/cat /proc/syslock/status | /bin/grep -vE "INIT|UNLO"
    fi
  
    # hasmtest dump
    $CHASSISCMD  /fabos/rbin/hasmtest dump 1

    # hasm.log
    $CATFILE /var/log/hasm.log

    # shm.log
    $CATFILE /var/log/shm.log

    # fsslo.log
    $CATFILE /var/log/fsslo.log

    # hadump.panic
    $CATFILE /var/log/hadump.panic

    # hasm.log.save
    $CATFILE /var/log/hasm.log.save

    # fos_bootup_log
    $CATFILE /var/log/fos_bootup_log

    # fos_bootup_log
    $CATFILE /var/log/firm_chksum.log

    # fos_bootup_log
    $CATFILE /var/log/firm_intg_mon.log

    # fos_bootup_log
    $CATFILE /var/log/firm_intg_mon.log.save

    # fsslo.log in secondary partition
    $CATFILE /mnt/var/log/fsslo.log

    # hasm.log in secondary partition
    $CATFILE /mnt/var/log/hasm.log

    # shm.log in secondary partition
    $CATFILE /mnt/var/log/shm.log

    # fsslo.log in secondary partition
    $CATFILE /mnt/var/log/fsslo.log

    # hasm.log in secondary partition
    $CATFILE /mnt/var/log/hasm.log

    # fos_bootup_log in mnt
    $CATFILE /mnt/var/log/fos_bootup_log

    # fos_bootup_log
    $CATFILE /mnt/var/log/firm_chksum.log

    # fos_bootup_log
    $CATFILE /mnt/var/log/firm_intg_mon.log

    # fos_bootup_log
    $CATFILE /mnt/var/log/firm_intg_mon.log.save

    # shm.log in secondary partition
    $CATFILE /mnt/var/log/shm.log

    # ISC related /proc entries
    $CATFILE /proc/isc/SWBD$sw_platform/sap
    $CATFILE /proc/isc/SWBD$sw_platform/epd
    $CATFILE /proc/isc/SWBD$sw_platform/dropped
    $CATFILE /proc/isc/SWBD$sw_platform/logged
    $CATFILE /proc/isc/sso

    $CATFILE /proc/hasm/ham

    $CATFILE /var/log/bc.history

    $CATFILE /var/log/bc.history.prev

    $CATFILE /mnt/var/log/bc.history

    $CATFILE /mnt/var/log/bc.history.prev

    # clp logs
    $CATFILE /var/log/license.log
    $CATFILE /var/log/license.log.save
    $CATFILE /etc/fabos/clp.conf
    $CHASSISCMD /fabos/cliexec/licadmin -d

    #ras_ffdc.conf
    $CATFILE /etc/fabos/ras_ffdc.conf

    # syslog IP address config
    $CHASSISCMD /fabos/sbin/syslogadmin --show -ip

    # syslog-ng conf
    $CATFILE /etc/syslog-ng/syslog-ng.template
    $CATFILE /etc/syslog-ng/syslog-ng.conf
    for syslog_ca in `/bin/ls -tr /etc/syslog-ng/ca.d`
    do
     	$CATFILE $syslog_ca
    done

    for syslog_dbg in `/bin/ls -tr /var/log/syslog*`
    do
     	$CATFILE $syslog_dbg
    done

    # fabos.log, fabos scrip log
    $CATFILE /var/log/fabos.log
    $CATFILE /tmp/insmod.log
	
    # Collect EULA acceptance record and eula file
    $CATFILE /etc/fabos/eula.txt
    $CHASSISCMD /fabos/cliexec/eula_fal -d

    $CHASSISCMD unlink_files

    # DFT related logs
    $CATFILE /var/log/dft.log
    $CHASSISCMD /fabos/rbin/dft --show -all
    $CATFILE /var/log/dft_cli.log

    # daemon logs from primary
    for daemon_log in `/bin/ls -t1 /var/log/daemon.log* 2> /dev/null`
    do
        $CATFILE $daemon_log
    done

    # daemon logs from secondary
    for daemon_log in `/bin/ls -t1 /mnt/var/log/daemon.log* 2> /dev/null`
    do
        $CATFILE $daemon_log
    done
}



# *******************************************
# Collect infra supportsave data
# *******************************************
start_infra()
{

    if [ $MULTIBLADE == "TRUE" ]
    then
      # Output of RON
      $CHASSISCMD /fabos/sbin/ron --show
    fi
    
    if [ $isWM = yes ]; then
      # MLT stats 
      if [ ! -d "/proc/mlt" ] ; then
	  $ECHO "MLT not enabled"
      else
	  $ECHO "Dumping MLT (Memory Leak Tracking) Information - KMALLOC SIZE SORTED"
	  $CHASSISCMD /bin/mlt -s 20
	  for(( i = 1 ; i < 21; i++ ))
	  do
	      $CHASSISCMD /bin/mlt -d $i
	  done
	  $ECHO "Dumping MLT (Memory Leak Tracking) Information - KMALLOC COUNT SORTED"
	  $CHASSISCMD /bin/mlt -t 20
	  for(( i = 1 ; i < 21; i++ ))
	  do
	      $CHASSISCMD /bin/mlt -d $i
	  done
	  $ECHO "Dumping MLT (Memory Leak Tracking) Error Stats"
	  $CATFILE /proc/mlt/stats
      fi

      # MLT KL stats
      if [ ! -d "/proc/mlt_kl" ] ; then
	  $ECHO "MLT_KL not enabled. Can be enabled by adding mlt_kl to boot args"
      else
	  $ECHO "Dumping MLT (Memory Leak Tracking) Kmalloc large Info - SIZE SORTED"
	  $CHASSISCMD /bin/mlt_kl -s 20
	  for(( i = 1 ; i < 21; i++ ))
	  do
	      $CHASSISCMD /bin/mlt_kl -d $i
	  done

	  $ECHO "Dumping MLT (Memory Leak Tracking) kamlloc large Info - COUNT SORTED"
	  $CHASSISCMD /bin/mlt_kl -t 20
	  for(( i = 1 ; i < 21; i++ ))
	  do
	      $CHASSISCMD /bin/mlt_kl -d $i
	  done

	  $ECHO "Dumping MLT (Memory Leak Tracking) Error Stats"
	  $CATFILE /proc/mlt_kl/stats
      fi

      # MLT VM stats
      if [ ! -d "/proc/mlt_vm" ] ; then
	  $ECHO "MLT_VM not enabled. Can be enabled by adding mlt_vm to boot args"
      else
	  $ECHO "Dumping MLT (Memory Leak Tracking) vmalloc Info - SIZE SORTED"
	  $CHASSISCMD /bin/mlt_vm -s 20
	  for(( i = 1 ; i < 21; i++ ))
	  do
	      $CHASSISCMD /bin/mlt_vm -d $i
	  done

	  $ECHO "Dumping MLT (Memory Leak Tracking) vamlloc Info - COUNT SORTED"
	  $CHASSISCMD /bin/mlt_vm -t 20
	  for(( i = 1 ; i < 21; i++ ))
	  do
	      $CHASSISCMD /bin/mlt_vm -d $i
	  done

	  $ECHO "Dumping MLT (Memory Leak Tracking) Error Stats"
	  $CATFILE /proc/mlt_vm/stats
      fi
    fi

    # XPRT related /proc entries
    xprt_f=`/usr/bin/find /proc/xprt -print 2> /dev/null | grep -e xcp -e htbt`
    for proc_f in $xprt_f
    do
        $CATFILE $proc_f
    done

    # need make this to be SS module
    if [ "$FABOS_OFF" = "FALSE" ]
    then
    $ECHO "/proc/fabos/blade/$slot/info & pt-prop:"
    $CHASSISCMD get_fcip_port_info
    fi

    # sboot --show
    $CHASSISCMD /sbin/sboot --show

    # fwdl.log
    $CATFILE /var/log/fwdl.log

    # fwdl.log.save
    $CATFILE /var/log/fwdl.log.save
    # fwdl.log in secondary partition
    $CATFILE /mnt/var/log/fwdl.log

    # fwdl.log.save in secondary partition
    $CATFILE /mnt/var/log/fwdl.log.save

    # CCM log
    $CATFILE /var/log/cfglog
    $CATFILE /mnt/var/log/cfglog
    
    CCM_PATH="/etc/fabos/config/scripts" 
    MNT_CCM_PATH="/mnt$CCM_PATH"

    $CATFILE $CCM_PATH/ccm_version.conf
    $CATFILE $MNT_CCM_PATH/ccm_version.conf

    CFGPOSTPLAY_PATH="$CCM_PATH/cfgpostplay"
    CFGREST_PATH="$CCM_PATH/cfgrest"
    CFGSYNC_PATH="$CCM_PATH/cfgsync"

    for cfgfile in `ls -1 $CFGPOSTPLAY_PATH | sort -nr`
    do
	$CATFILE $CFGPOSTPLAY_PATH/$cfgfile
    done
    for cfgfile in `ls -1 $CFGREST_PATH | sort -nr`
    do
	$CATFILE $CFGREST_PATH/$cfgfile
    done
    for cfgfile in `ls -1 $CFGSYNC_PATH | sort -nr`
    do
	$CATFILE  $CFGSYNC_PATH/$cfgfile
    done

    # Dump cfg DB files
    for cfgfile in `/bin/ls -tr /var/log/cfg_db_info*`
    do
	$CATFILE $cfgfile
    done
    for cfgfile in `/bin/ls -tr /mnt/var/log/cfg_db_info*`
    do
	$CATFILE $cfgfile
    done


    # Dump the memorystatus files

    for memfile in `/bin/ls -tr /var/log/mstatdir/memorystatus*`
    do
     	$CATFILE $memfile
    done

    for memfile in `/bin/ls -tr /mnt/var/log/mstatdir/memorystatus*`
    do
     	$CATFILE $memfile
    done

    for memfile in `/bin/ls -tr /var/log/mstatdir/cachestatus*`
    do
        $CATFILE $memfile
    done

    for memfile in `/bin/ls -tr /mnt/var/log/mstatdir/cachestatus*`
    do
        $CATFILE $memfile
    done

    # Collect the preinst postinst check-features bash logs
    $CATFILE /var/log/preinst.log
    $CATFILE /var/log/postinst.log
    $CATFILE /var/log/check-feature.log

    pizzabox=$(/fabos/link_bin/hashow | grep -c "Not supported on this platform") 2>/dev/null
    if [ $pizzabox -eq 1 ]
    then
	$CHASSISCMD	/fabos/link_bin/vlan --show
    fi
    
    # Collect FFDC Trace OD files
    if [ $isWM = yes ]
    then
	start_trace_od
    else
	start_trace_ata
    fi
}



# *******************************************
# Collect CLP related data file
# *******************************************
start_clp()
{
    $CATFILEC /etc/fabos/clp.conf
    $CHASSISCMD /fabos/cliexec/licadmin -d
    $CATFILEC /var/log/license.log
    $CATFILEC /var/log/license.log.save
    $CATFILEC /mnt/var/log/license.log
    $CATFILEC /mnt/var/log/license.log.save
    $CATFILEC /var/log/clp.log

    #version.conf for CP and BP
    $CATFILE /etc/version.conf
    $CATFILE /mnt/etc/version.conf

  if [ "$FABOS_OFF" = "FALSE" ]
  then
    $SWITCHCMD /fabos/sbin/myid

    $CHASSISCMD /sbin/chkconfig

    $CHASSISCMD firmwareshow -v

    $CHASSISCMD /fabos/cliexec/firmwareshow --history

    $CHASSISCMD firmwaredownloadstatus

    #CLI history
    $CHASSISCMD /fabos/sbin/clihistory --showall

    $CHASSISCMD /fabos/cliexec/licenseidshow 2> /dev/null
    /bin/echo ""

    $CHASSISCMD /fabos/link_sbin/license --show 2> /dev/null
    /bin/echo ""

    $CHASSISCMD /fabos/link_sbin/license --show -port 2> /dev/null
    /bin/echo ""
  fi

    # 7ab. license backdoor
    if [ -f /etc/fabos/.licensedisable ]
    then
    /bin/echo "License backdoor is installed"
    else
    /bin/echo "License backdoor is NOT installed"
    fi
    /bin/echo ""

    # 7b. licenses file
    if [ -f /etc/fabos/licenses ]
    then
    $CHASSISCMD /bin/cat -v /etc/fabos/licenses
    fi
    /bin/echo "===================================================================="
    /bin/echo ""

    # 7c. licensedb file
    if [ -f /etc/fabos/licensedb ]
    then
    $CHASSISCMD /bin/cat -v /etc/fabos/licensedb
    fi
    /bin/echo "===================================================================="
    /bin/echo ""

    #7e. License certificates 
    $CHASSISCMD /bin/ls -l /etc/fabos/license_certificates

    # Print /etc/fabos/license_certificates
    certificates="`/bin/ls -d /etc/fabos/license_certificates/*.xml 2> /dev/null;`"
    for certificate in $certificates ; do
       $CHASSISCMD /bin/cat -v $certificate
   done
   /bin/echo "===================================================================="
   /bin/echo ""
}

# *******************************************
# Collect INFRA User data
# *******************************************
start_infra_user()
{
    $ECHO "start_infra_user"
}

# *******************************************
# Collect INFRA Internal supportsave data
# *******************************************
start_infra_internal()
{
    $ECHO "start_infra_internal"
}

cmd_root()
{
     $SSCMD $@ "--sscommand=1" -l $ssutil_log -a
}

ROOTCMD="cmd_root"


# *******************************************
# Collect test data
# *******************************************
start_test()
{
    $ECHO "start_test"
    CCM_PATH="/etc/fabos/config/scripts" 
    MNT_CCM_PATH="/mnt$CCM_PATH"

    $CATFILE $CCM_PATH/ccm_version.conf
    $CATFILE $MNT_CCM_PATH/ccm_version.conf

    CFGPOSTPLAY_PATH="$CCM_PATH/cfgpostplay"
    CFGREST_PATH="$CCM_PATH/cfgrest"
    CFGSYNC_PATH="$CCM_PATH/cfgsync"

    for cfgfile in `ls -1 $CFGPOSTPLAY_PATH | sort -nr`
    do
	$CATFILE $CFGPOSTPLAY_PATH/$cfgfile
    done
    for cfgfile in `ls -1 $CFGREST_PATH | sort -nr`
    do
	$CATFILE $CFGREST_PATH/$cfgfile
    done
    for cfgfile in `ls -1 $CFGSYNC_PATH | sort -nr`
    do
	$CATFILE  $CFGSYNC_PATH/$cfgfile
    done

#    $SWITCHCMD /fabos/cliexec/ssave_infra.sh --switchcmd

#    $ROOTCMD /bin/cat /proc/slabinfo
#    sleep 180

#    $ECHO "use ssave.util CHASSISCMD"
#    $CHASSISCMD /bin/cat /var/log/sslog
#    $ECHO "not use ssave.util"
#    time /bin/cat /var/log/sslog
#    $ECHO "use ssave.util SWITCHCMD"
#    $SWITCHCMD /fabos/cliexec/bd_debug
#    time /fabos/cliexec/bd_debug
}


display_parallel_usage () {
    echo "Usage: $PROGNAME --parallel -[hl:d:h:u:p:s:o:t:r:]";
    echo "     -l [scp | ftp | sftp] # supportsave protocol";
    echo "     -d [directory]        # supportsave directory";
    echo "     -h [host]             # supportsave host";
    echo "     -u [user]             # supportsave user";
    echo "     -p [password]         # supportsave password";
    echo "     -s [worker]           # parallel processing worker number";
    echo "     -o [load average]     # load average limit";
    echo "     -t [timeout]          # supportsave timeout";
    echo "     -r [repeat]           # number of time repeat the supportsave";
    echo "     -v                    # this help";
    exit 1;
}

start_paraellel_ss_loadaverage()
{
    for i in $(seq 1 12)
    do
	loadavg=`uptime | awk '{print $10+0}'`
        # bash doesn't understand floating point
        # so convert the number to an interger
	thisloadavg=`echo $loadavg|awk -F \. '{print $1}'`
	if [ "$thisloadavg" -ge "1" ]; then
	    sleep 10
	fi
    done
}



# *******************************************
# Collect test data
# /fabos/cliexec/ssave_infra.sh --parallel -lscp -dSS -h 10.210.208.250 -u jc401101 -p Blue1hil# -s30
# *******************************************
start_parallel_ss()
{
#    $ECHO "args $@"
    $ECHO "supportsave paraelle processing test"
    $ECHO "supportsave paraelle processing test" > "$parallel_ss_test"
    LOAD=0
    REPEAT=1
    TEST=0
    TIMEOUT=1

    while getopts "vl:d:h:u:p:s:o:t:r:x" opt
    do case $opt in
	l) PROTO=$OPTARG ;;
	d) DIR=$OPTARG ;;
	h) HOST=$OPTARG ;;
	u) USER=$OPTARG ;;
	p) PASSWORD=$OPTARG ;;
	s) WORKER=$OPTARG ;;
	o) LOAD=$OPTARG ;;
	t) TIMEOUT=$OPTARG ;;
	r) REPEAT=$OPTARG ;;
	x) TEST=1 ;;
	v ) display_parallel_usage ;;
	\? ) display_parallel_usge ;;
	* ) display_parallel_usage ;;
    esac
    done

    if [ -z ${HOST+x} ]; then $ECHO "Invalid input HOST"; exit; fi
    if [ -z ${DIR+x} ]; then $ECHO "Invalid input DIR"; exit; fi
    if [ -z ${HOST+x} ]; then $ECHO "Invalid input HOST=$HOST"; exit; fi
    if [ -z ${USER+x} ]; then $ECHO "Invalid input USER"; exit; fi
    if [ -z ${PASSWORD+x} ]; then $ECHO "Invalid input PASSWORD"; exit; fi
    if [ -z ${PROTO+x} ]; then $ECHO "Invalid input PROTO"; exit; fi
    if [ -z ${WORKER+x} ]; then $ECHO "Invalid input WORKER"; exit; fi

    $ECHO "start_parallel_ss test WORKER=$WORKER LOAD=$LOAD REPEAT=$REPEAT" > "$parallel_ss_test"

    $ECHO "PROTO=$PROTO"
    $ECHO "DIR=$DIR"
    $ECHO "HOST=$HOST"
    $ECHO "USER=$USER"
    $ECHO "PASSWORD=$PASSWORD"
    $ECHO "WORKER=$WORKER"
    $ECHO "LOAD=$LOAD"
    $ECHO "REPEAT=$REPEAT"
    $ECHO "TIMEOUT=$TIMEOUT"

    errclear
    $ECHO "Defaul:/fabos/cliexec/supportsave -n -l$PROTO -d$DIR -h $HOST -u $USER -p $PASSWORD"
    /fabos/cliexec/supportsave -n -l$PROTO -d$DIR -h $HOST -u $USER -p $PASSWORD
    /bin/cat /var/log/ss_module_log >> $parallel_ss_test

    $ECHO "Legacy:/fabos/cliexec/supportsave -n -l$PROTO -d$DIR -h $HOST -u $USER -p $PASSWORD -s"
    /fabos/cliexec/supportsave -n -l$PROTO -d$DIR -h $HOST -u $USER -p $PASSWORD -s
    /bin/cat /var/log/ss_module_log >> $parallel_ss_test

    #for w_idx in $(seq 1 $WORKER)
    for w_idx in $(seq $WORKER -1 1)
    do
	if [ $LOAD -eq 0 ]
	then
	    for k in $(seq 1 $REPEAT)
	    do
	    $ECHO "/fabos/cliexec/supportsave -n -l$PROTO -d$DIR -h $HOST -u $USER -p $PASSWORD -t $TIMEOUT -w $w_idx -o 20"
	    /fabos/cliexec/supportsave -n -l$PROTO -d$DIR -h $HOST -u $USER -p $PASSWORD -w$w_idx -o20
	    perf_rc=$?
	    /bin/cat /var/log/ss_module_log >> $parallel_ss_test
	    if [ $perf_rc -ne 0 -a "$perf_rc" -ne "-13" ]; then
		$ECHO "supportsave paraelle processing performance test error, test terminated" >> $parallel_ss_test
		exit $perf_rc
	    fi
	    start_paraellel_ss_loadaverage
	    done
	else
	    for j in $(seq 1 $LOAD)
	    do
	      for k in $(seq 1 $REPEAT)
	      do
	      if [ $j -le $(($w_idx+2)) ]; then
                #/fabos/cliexec/supportsave -n -lscp -dSS -h 10.210.208.250 -u jc401101 -p Blue1hil# -w1
	        $ECHO "/fabos/cliexec/supportsave -n -l$PROTO -d$DIR -h $HOST -u $USER -p $PASSWORD -w $w_idx -o $j"
	        if [ $TEST -eq 0 ]; then
		  /fabos/cliexec/supportsave -n -l$PROTO -d$DIR -h $HOST -u $USER -p $PASSWORD -w$w_idx -o$j
		  perf_rc=$?
		  /bin/cat /var/log/ss_module_log >> $parallel_ss_test
		  if [ $perf_rc -ne 0 -a "$perf_rc" -ne "243" -a "$perf_rc" -ne "242" ]; then
		    $ECHO "supportsave paraelle processing performance test error=$perf_rc, test terminated"
	#	    exit $perf_rc
		  fi
		  start_paraellel_ss_loadaverage
		fi
	      fi
	      done
	    done
	fi
    done

    errdumpall | grep SS-5005
    /bin/cat "$parallel_ss_test" | grep Summary
}


# *******************************************
# Collect FOS config
# *******************************************
start_infra_foscfg()
{
	$CHASSISCMD /fabos/cliexec/configshow -all | /bin/cat # the cat at end of pipe avoids more's paging

	$CATFILE /var/log/config_updown.log

	$CATFILE /var/log/config_updown.log.save
	$CATFILE /var/log/config_show.log

	$CATFILE /mnt/var/log/config_updown.log

	$CATFILE /mnt/var/log/config_updown.log.save
	$CATFILE /mnt/var/log/config_show.log

	#the below get executed only if configshow fails
	#cat chassis section of config file
	temp=`/bin/ls /tmp/config_chassis*`
	for file in $temp
	do
		$CATFILE $file
	done

	#cat default switch section of config file
	temp=`/bin/ls /tmp/sw*`
	for file in $temp
	do
		$CATFILE $file
	done
}


start_trace_od()
{
    FILE_SIZE_50M=52428800

    if [ "$FABOS_OFF" = "FALSE" ]
    then
        Date=`/bin/date +%Y%m%d%H%M`
        $CHASSISCMD /fabos/cliexec/rasod -d -w-2 -m3 -y4 -t 180 -o /var/trace/tracess.$Date.trc.od
    fi

    if [ ! -e "/var/trace/trace_id.dat" ]
    then
        echo "File: /var/trace/trace_id.dat not found"
        $CHASSISCMD /fabos/rbin/tracedbadd -e
    fi

    nfile=`ls -l /var/trace/* | wc -l`
    mnt_nfile=`ls -l /mnt/var/trace/* | wc -l`

    $ECHO "/var/trace od file=$nfile /mnt/var/trace od file=$mnt_nfile"

    if [ "$mnt_nfile" -eq 0 ]
    then
        $ECHO "No /mnt trace found " > /mnt/var/trace/ffdc_trace_od
    fi

    if [ "$nfile" -eq 0 ]
    then
        $ECHO "No trace found " > /var/trace/ffdc_trace_od
        $CHASSISCMD tar -cvf /var/log/TRACE_FFDC_OD.tar /var/trace/ffdc_trace_od /mnt/var/trace/*
    else
        free_space=`/bin/df --block-size=1 /| grep -v Filesystem | awk '{print $4}'`
        estimate_tarsize=`tar -czf - /var/trace/* /mnt/var/trace/* | wc -c 2> /dev/null`

        min_size=`/usr/bin/expr $free_space - $FILE_SIZE_50M`

	$ECHO "CF free space=$free_space estimate trace size=$estimate_tarsize available CF=$min_size"

        # In the case of not enough CF, just need to collect tracess.xxxxx.xx file
        if [ $free_space -lt $estimate_tarsize ]
        then
            $ECHO "Not enough free CF=$free_space for all traceod=$estmate_tarsize, collect tracess od only"
            $CHASSISCMD tar -cvf /var/log/TRACE_FFDC_OD.tar /var/trace/tracess* /var/trace/trace_id.dat

            /fabos/cliexec/errlogtest -i TRCE-5022 -a $Date
            return;
        fi

        # tar tracepd & tracess only if estimate tar > (freespace - 50MB)
        if [ $estimate_tarsize -gt $min_size ]
        then
	    $ECHO "Not enough free CF=$free_space for all traceod=$estmate_tarsize, collect tracess and tracepd"
            $CHASSISCMD tar -cvf /var/log/TRACE_FFDC_OD.tar /var/trace/tracess* /var/trace/trace_id.dat
            pdfile=`ls -l /var/trace/tracepd* | wc -l`
            if [ "$pdfile" -ge 1 ] ;then
                $CHASSISCMD tar -rvf /var/log/TRACE_FFDC_OD.tar /var/trace/tracepd*
            fi
            /fabos/cliexec/errlogtest -i TRCE-5022 -a $Date
        else
	    # tar all trace od files
	    $ECHO "free CF=$free_space trace od size=$estmate_tarsize, collect all trace od files"
            $CHASSISCMD tar -cvf /var/log/TRACE_FFDC_OD.tar /var/trace/* /mnt/var/trace/*

	    # Moved the removal of traceod* files to RAS_POST module in case upload failure
        fi
    fi
}

#
# collect FOS oFF SS trace data file
#
start_trace_ata()
{
    # collect tracedump here if FOS OFF SS is invoked. If FOS is ON, trace should be collected as
    # defined in supportsave.conf
    if [ $fabos_off = no ]
    then
#	$ECHO "FOS is on, trace files are collected as supportsave.conf defined" > /var/trace/ffdc_trace_od
#        tar -cvf /var/log/TRACE_FFDC_OD.tar /var/trace/ffdc_trace_od
	return;
    fi

    #CTRACE_OLD,/bin/cat /var/tracedump.dmp, , ,N,Y,N,Y,Y,3,
    #CTRACE_OLD_MNT,/bin/cat /mnt/var/tracedump.dmp, , ,N,Y,N,N,Y,3,
    #CTRACE_NEW,/fabos/sbin/tracedump -z; /bin/cat /var/tracedump.dmp, , ,N,Y,N,Y,Y,4,

    Date=`/bin/date +%Y%m%d%H%M`
    dmpfile=/var/trace/tracess.$Date.old.tracedump.dmp
    /bin/cp /var/tracedump.dmp $dmpfile
    $CHASSISCMD $GZIP -f $dmpfile

    if [ -f "$dmpfile.gz" ]
    then
	$CHASSISCMD tar -cvf /var/log/TRACE_FFDC_OD.tar $dmpfile.gz
    else
	$ECHO "$dmpfile.gz does not exist"
    fi

    /fabos/sbin/tracedump -z;
    Date=`/bin/date +%Y%m%d%H%M`
    dmpfile=/var/trace/tracess.$Date.new.tracedump.dmp
    /bin/cp /var/tracedump.dmp $dmpfile
    $CHASSISCMD $GZIP -f $dmpfile
    if [ -f "$dmpfile.gz" ]
    then
	$CHASSISCMD tar -rvf /var/log/TRACE_FFDC_OD.tar $dmpfile.gz
    else
	$ECHO "$dmpfile.gz does not exist"
    fi

    Date=`/bin/date +%Y%m%d%H%M`
    dmpfile=/var/trace/tracess.$Date.mnt.tracedump.dmp
    /bin/cp /var/tracedump.dmp $dmpfile
    $CHASSISCMD $GZIP -f $dmpfile
    if [ -f "$dmpfile.gz" ]
    then
	$CHASSISCMD tar -rvf /var/log/TRACE_FFDC_OD.tar $dmpfile.gz
    else
	$ECHO "$dmpfile.gz does not exist"
    fi

    /bin/rm -f /var/trace/tracess.*
}

# *******************************************
# Collect post supportsave data
# *******************************************
start_post()
{     
    if [ "$FABOS_OFF" = "FALSE" ]
    then
      $CATFILE /proc/consolelog | grep -Ev "Mail Recipient|Mail From Address|User name"
      if [ -f /var/log/prev_consolelog ]; then
		$CATFILE /var/log/prev_consolelog | grep -Ev "Mail Recipient|Mail From Address|User name"
      fi					
    fi

    if [ -f /proc/dp0_consolelog ]; then
        $CHASSISCMD /sbin/bootenv dp_console
        $CATFILE  /proc/tty/driver/serial
	$CATFILE /proc/dp0_consolelog
    fi

    if [ -f /proc/dp1_consolelog ]; then
	$CATFILE /proc/dp1_consolelog
    fi

    $CATFILE_RM /var/log/assert.log

    $CATFILE /var/log/config_updown.log
    $CATFILE /var/log/config_show.log

    $CATFILE /proc/kwm/WMEM/logs

    $CATFILE /var/log/logrotate.status

   # Print /var/log/messages
    file_no="`ls /var/log/messages*`"
    for file in $file_no ; do
	$CATFILE $file
    done

    file_no="`ls /mnt/var/log/messages*`"
    for file in $file_no ; do
	$CATFILE $file
    done

    if [ "$FABOS_OFF" = "FALSE" ]
    then
      $CHASSISCMD /fabos/cliexec/errdumpall

      # Collect the Audit logs
      $CHASSISCMD	/fabos/sbin/auditcfg --show -filter
      $CHASSISCMD	/fabos/sbin/auditdump -s
    fi

    $CATFILE /var/log/config_updown.log		
    $CATFILE /var/log/config_show.log		

    # SPSM log
    $CATFILE /var/log/sysrmd.log
    $CHASSISCMD /fabos/rbin/spsm --show
    $CHASSISCMD /fabos/rbin/spsm --history show
    $CHASSISCMD /fabos/rbin/spsm --record all

    # Removing the traceod* files here instead of RAS modules
    # to avoid missing of trace files in case of SS upload failed.
    if [ $isWM = yes ]; then
      $ECHO "Removing the traceod* files "
      /bin/rm -f /var/trace/*.od      >/dev/null 2>&1
      /bin/rm -f /var/trace/tracepd*  >/dev/null 2>&1
      /bin/rm -f /mnt/var/trace/*.od  >/dev/null 2>&1
      /bin/rm -f /mnt/var/trace/ffdc_trace_od  >/dev/null 2>&1
    fi

    $CATFILE_RM /var/log/ss_ftp_dbg_log

    # SS utility (ftp, zip, tar ..) CLI error log */
    $CATFILE /var/log/ss_util_err.log
 
    # SS log
    $CATFILE /var/log/sslog

    # SS module CLI log
    $CATFILE_RM /var/log/ssave.sh.log

    if [ -e "$parallel_ss_test" ]
    then
	$CATFILE "$parallel_ss_test"
	$CATFILE /var/log/ss_module_log
    else
        # record SS module statistic and display at end of RAS_POST */
	$CATFILE_RM /var/log/ss_module_log
    fi
    unset_lscfg_test_post
}
top_ten_files()
{
  $ECHO "********************************************************"
  $ECHO "        Top Ten Most Disk Consuming Files         "
  $ECHO "********************************************************"
  /usr/bin/find / -xdev -type f -fstype nfs -prune -o -path /mnt -prune -o -printf '%s %p\n'|sort -nr|head
  $ECHO "********************************************************"
}

# *******************************************
# Collect Fabos-off acquirable info
# *******************************************
start_fabos_off()
{
   $CHASSISCMD /usr/bin/top -n 1

   $CHASSISCMD /sbin/ethtool eth0

   $CHASSISCMD /fabos/cliexec/mii-tool -vvv

   $CHASSISCMD /bin/df -h

   $CHASSISCMD unlink_files

   $CHASSISCMD top_ten_files

   $CHASSISCMD /usr/bin/du -xh /

   $CHASSISCMD /bin/ps exfcl

   $CHASSISCMD /bin/rpm -qa

   $CHASSISCMD /bin/cat /var/log/dmesg

   $CHASSISCMD /bin/dmesg

   $CHASSISCMD /bin/cat /etc/fstab

   $CHASSISCMD /bin/cat /etc/mtab

   $ECHO "printing proc entries"
   if [ "$STANDBY" = "FALSE" ]
   then
	proc_entries="cmdline,cpuinfo,devices,filesystems,interrupts,meminfo,modules,mounts,mtd,partitions,pci,slabinfo,stat,tty/drivers,uptime,version"
   else
	proc_entries="cmdline,cpuinfo,devices,filesystems,interrupts,meminfo,modules,mounts,mtd,partitions,pci,slabinfo,stat,tty/drivers,uptime,version"
   fi
   for proc_entry in `$ECHO $proc_entries | /usr/bin/tr "," "\n"`
   do
      $CHASSISCMD /bin/cat /proc/$proc_entry
   done

   $CHASSISCMD /usr/bin/find /core_files /mnt/core_files -type f

   $CHASSISCMD /bin/rpm -Va

   $CHASSISCMD /usr/bin/tail -200 /var/log/user.log

   cmds="/sbin/bootenv,/sbin/sin,/bin/df,/sbin/ifconfig,/sbin/route,/bin/hostname"
   for cmd in `$ECHO $cmds | /usr/bin/tr "," "\n"`
   do
      $CHASSISCMD $cmd
   done

   $CHASSISCMD /sbin/arp -n

   $CHASSISCMD /sbin/ethtool eth0

   $CHASSISCMD /fabos/cliexec/mii-tool -vv eth0

   $CHASSISCMD /sbin/ethtool --statistics eth0

   $CHASSISCMD /sbin/ip -s link

   $CHASSISCMD /sbin/ip -s addr

   $CHASSISCMD /bin/cat /proc/net/tcp

   $CHASSISCMD /bin/cat /proc/net/udp

   $CHASSISCMD /bin/cat /proc/net/netstat

   $CHASSISCMD /bin/cat /proc/net/sockstat
}


#silicond support
silicond_dump ()
{
    PID= ps ax | grep silicond | awk '{print $1}'
    kill -10 $PID
}

# To handle multiple params
# for param in $@
#  do
#    if [ "$param" = "--of" ]
#    then
#      outf_enable=1	 
#    fi
#  done

#Adding support for silicond stats
# silicond_dump	
 for param in $@
  do
    if [ "$param" = "--pre" ]
    then
      $EXEC_GROUP start_pre
    fi

    if [ "$param" = "--raslog" ]
    then
#      $EXEC_GROUP start_raslog
      $CAT /etc/raslog.int /etc/raslog.ext
    fi

    if [ "$param" = "--internal" ]
    then
	$EXEC_GROUP start_infra_internal
    fi

    if [ "$param" = "--clp" ]
    then
      $EXEC_GROUP start_clp
    fi

    if [ "$param" = "--infra" ]
    then
      $EXEC_GROUP start_infra
    fi


    if [ "$param" = "--foscfg" ]
    then
	$EXEC_GROUP start_infra_foscfg
    fi

    if [ "$param" = "--post" ]
    then
	$EXEC_GROUP start_post
    fi

    if [ "$param" = "--fabosoff" ]
     then
     $EXEC_GROUP start_fabos_off
    fi

    if [ "$param" = "--switchcmd" ]
    then
	echo "FABOS_SWITCHNO=$FABOS_SWITCHNO"  #-1:chassis or current switch context (MYSWITCH)
	echo "CHASSIS_ROLEID=$CHASSIS_ROLEID"  #0:chassis permission, -1: none chassis permission
	echo "ROLE_ID=$ROLE_ID" 
	echo "HOME_VF=$HOME_VF"
	echo "CURRENT_VF=$CURRENT_VF"          #current FID
    fi

    if [ "$param" = "--test" ]
    then
	$EXEC_GROUP start_test
    fi

    if [ "$param" = "--parallel" ]
    then
	shift
	start_parallel_ss "$@"
    fi

    if [ "$param" = "--unlink" ]
    then
	$EXEC_GROUP unlink_files
    fi

    RETVAL=`echo $?`
    exit $RETVAL
  done

