#!/bin/sh

#
# This script is applicable only for Extension platforms.
# This script gets inokved as part of FFDC trigger when DP reports Soft Fault to
# CP after which DP gets reset by CP. This script tries to get some in-memory
# stats and other debug data from DP before DP gets reset by CP.
#

slot=$1
dp=$2
sw_platform=`/sbin/sin 2>/dev/null | sed -n 's/^.*SWBD\([^,]*\),.*/\1/p'`

# Valid values of "dp" are 0, 1, 2 where 2 means get data for both DPs
if [ $dp -ne 0 -a $dp -ne 1 -a $dp -ne 2 ]
then
	echo "### ERROR: Invalid dpid $dp ###"
	exit 1
fi

# For Awing, dp value must be only 0
if [ $sw_platform -eq 178 ]
then
	dp=0
fi

# Prepare list of DPs from whch logs need to be collected
case "$dp" in
	"2" ) dp_list="0 1";;
	* ) dp_list="$dp";;
esac

get_dp_data()
{
	echo "`date` Start: Get data from DP ${1}"
	echo
	ping -q -W 2 -c 1 ${1} > /dev/null
	if [ $? -eq 0 ]; then
		echo "/******* DP ${1} is reachable *******/"
		echo "/******* rsh ${1} uptime *******/"
		rsh ${1} "uptime" 2> /dev/null
		echo
		echo "/******* rsh ${1} Latest Syslog *******/"
		rsh ${1} "cat /var/log/messages | tail -128" 2> /dev/null
		echo
		echo "/******* rsh ${1} Xprt HTBT stats *******/"
		rsh ${1} "cat /proc/xprt/htbt*" 2> /dev/null
		echo
		rsh ${1} "cat /proc/extn/node" 2> /dev/null
		echo
		echo "/******* rsh ${1} Xprt XCP stats *******/"
		rsh ${1} "cat /proc/xprt/xcp*" 2> /dev/null
		echo
		echo "/******* rsh ${1} ISC stats *******/"
		rsh ${1} "cat /proc/isc/sso" 2> /dev/null
		echo
		rsh ${1} "cat /proc/extn/isc_stats" 2> /dev/null
		echo
		echo "/******* rsh ${1} Netstat *******/"
		rsh ${1} "netstat -i" 2> /dev/null
		echo
		echo "/******* rsh ${1} ifconfig & ethtool *******/"
		for mgmtif in `rsh ${1} "ls /sys/class/net/ | grep -v lo"`
		do
			rsh ${1} "/sbin/ifconfig $mgmtif" 2> /dev/null
			rsh ${1} "/usr/sbin/ethtool $mgmtif" 2> /dev/null
			rsh ${1} "/usr/sbin/ethtool -S $mgmtif" 2> /dev/null
		done
		echo
		echo "/******* rsh ${1} ARP *******/"
		rsh ${1} "/sbin/arp -a" 2> /dev/null
		echo
		active_cp_ip=`rsh ${1} "/fabos/bin/i2c_read -i" 2> /dev/null | awk '{printf $1}'`
		echo "/******* rsh ${1} Sockets state with Active CP $active_cp_ip *******/"
		rsh ${1} "netstat -nap" 2> /dev/null | grep $active_cp_ip
		echo
		echo "/******* rsh ${1} Running PS *******/"
		rsh ${1} top -b -n 1 | awk '$4 == "R"' 2> /dev/null
		echo
		echo "/******* rsh ${1} CPU Load *******/"
		rsh ${1} "cpu-load" 2> /dev/null
		echo
		echo "/******* rsh ${1} mount *******/"
		rsh ${1} "mount" 2> /dev/null
	else
		echo "/******* DP ${1} is not reachable *******/"
	fi
	echo
	echo "`date` End: Get data from DP ${1}"
}

get_cp_data()
{
	echo "`date` Start: Get data from CP"
	echo
	echo "/******* uptime *******/"
	uptime
	echo
	echo "/******* Xprt HTBT stats *******/"
	cat /proc/xprt/htbt*
	echo
	cat /proc/hasm/ham
	echo
	if [ `find /proc/xprt/ -name "xcp*" | wc -l` -gt 0 ]
	then
		echo "/******* Xprt XCP stats *******/"
		cat /proc/xprt/xcp*
		echo
	fi
	echo "/******* ISC stats *******/"
	cat /proc/isc/sso
	echo
	echo "/******* Netstat *******/"
	netstat -i
	echo
	# Get stats for Tftp server (tftp-port=69 & tftpd)
	echo "/******* Tftp server stats *******/"
	netstat -nap | grep -w -e 69 -e tftpd
	ps -ef | grep tftp | grep -v grep
	echo
	echo "/******* ifconfig & ethtool *******/"
	if [ $slot -eq 0 ]
	then
		b_p_if=eth1
	else
		b_p_if=eth2
	fi
	ifconfig $b_p_if
	ethtool $b_p_if 2> /dev/null
	ethtool -S $b_p_if 2> /dev/null
	echo
	echo "/******* ARP *******/"
	arp -a
	echo
	echo "`date` End: Get data from CP"
}

# Get stats for all DPs in the dp_list
for dp in $dp_list
do
	if [ $slot -eq 0 ]
	then
		dp_ip=dp${dp}
	else
		dp_ip=sl${slot}_dp${dp}
	fi

	# Get stats and debug data from DP over RSH
	get_dp_data $dp_ip
	echo
done

# Get stats of CP
get_cp_data

# Get some more additional info for all DPs in the dp_list
for dp in $dp_list
do
	if [ $slot -eq 0 ]
	then
		dp_ip=dp${dp}
	else
		dp_ip=sl${slot}_dp${dp}
	fi

	# Get sockets state with DP
	dp_ip_num=`arp -n $dp_ip 2> /dev/null | grep -v Address | awk '{print $1}'`
	echo "/******* Sockets state with DP $dp_ip_num *******/"
	netstat -nap 2> /dev/null | grep $dp_ip_num
	echo

	# Get EXDP chip's ISC stats
	exdp_idx=`expr $dp + 2`
	echo "/******* db $slot/0/$exdp_idx exdp misc do 1 27 *******/"
	/fabos/link_rbin/db $slot/0/$exdp_idx exdp misc do 1 27
	echo

	# For pizza box also dump DP's console o/p redirected to CP
	if [ $slot -eq 0 ]
	then
		echo "/******* /proc/dp${dp}_consolelog *******/"
		cat /proc/dp${dp}_consolelog
		echo
	fi
done
