#!/bin/sh
SRMD_DIR=/var/srmd_data/
SRMD_ARCHIVE_DIR=/var/srmd_archives/


mkdir -p $SRMD_ARCHIVE_DIR
#Check whether there is old data present
if [ -d "$SRMD_DIR" ]
then
	touch $SRMD_DIR/archived_srmd
	DATE=`date +"%F-%H.%M"`
	#Archive the directory
	tar zcf $SRMD_ARCHIVE_DIR/srmd_archive_$DATE.tgz $SRMD_DIR &> /dev/null
	sync
	#Clean up 
	rm -rf $SRMD_DIR/*
else
	mkdir -p $SRMD_DIR
fi

cd $SRMD_DIR

#Create the 5 seconds bucket. 12 X 5 seconds interval make 1 minute
for i in $(seq 0 1 1)
do
	cat /dev/null > srmd_sec_$i
done

#Create the 1 minute bucket. 60 minutes make one hour
for i in $(seq 0 1 59)
do
	cat /dev/null > srmd_minute_$i
done

#Create the 1 hour bucket. 24 hours make a day
for i in $(seq 0 1 23)
do
	cat /dev/null > srmd_hour_$i
done

#Create the day bucket. ~31 days make a month
for i in $(seq 0 1 30)
do
	cat /dev/null > srmd_day_$i
done

#Create the month bucket. 12 months make an year
for i in $(seq 0 1 11)
do
	cat /dev/null > srmd_month_$i
done

chmod a+r *
echo 1 > second_marker
echo 59 > minute_marker
echo 23 > hour_marker
echo 30 > day_marker
echo 11 > month_marker

#Find the number of cores
n_cores=`grep processor /proc/cpuinfo | wc -l | awk '{printf("%d", $1);}'`
while true
do
	#Work on the month bucket
	for month in $(seq 11 -1 0)
	do
		cat /dev/null > month_join
		#Work on the day bucket
		for day in $(seq 30 -1 0)
		do
			cat /dev/null > day_join
			#Work on the hour bucket
			for hour in $(seq 23 -1 0)
			do 
				cat /dev/null > hour_join
				#Work on the minute buckets
				for minute in $(seq 59 -1 0)
				do	
					cat /dev/null > minute_join
					#First lets work on the 5 second bucket. 
					for i in $(seq 1 -1 0) #prev: seq 11 -1 0
					do
						cat minute_join > temp_file
                        /usr/bin/vmstat 1 3 | /usr/bin/tail -n +5 | /bin/awk \
                            '{printf "%07d^TOTAL_CPU\t%d#0\n%07d^TOTAL_IOW\t%d#0\n%07d^TOTAL_SYS\t%d#0\n%07d^TOTAL_USR\t%d#0\n", \
                            0,100-$15, 0,$16, 0,$14, 0, $13}' > srmd_sec_$i
						pidstat -h | tail -n +4 |awk '{printf("%07d^%s\t%0.2f#%d\n", $2, $8, $6i, $7);}' >> srmd_sec_$i
						echo $i > second_marker
						#Add a column to the minute file also.
						join -a 2 temp_file srmd_sec_$i > minute_join 2> /dev/null
						sleep 28 #prev: sleep 5
					done #(1 -1 0)
					#Join the 2 buckets to form a minute of data and keep it.
					awk -v ncores=$n_cores '{ 
						for(i=0;i<ncores;++i) 
							core_count[i] = 0; 
						x = 0; 
						for(i=2;i<4;++i){ 
							split($i,core,"#"); 
							core_count[core[2]]+=1; 
							x+=$i; 
						} 
						printf("%s %.2f", $1, x/2.0); 
						for(i=0;i<ncores;++i) 
							printf ("#%.4f", core_count[i]/2.0); 
						printf("\n");}' minute_join > srmd_minute_$minute
					echo $minute > minute_marker
					cat hour_join > temp_hour
					#Add a column every minute into the hour file. For easier adding at the end.
					join -a 2 temp_hour srmd_minute_$minute > hour_join 2> /dev/null
				done #(60 -1 1)
				awk -v ncores=$n_cores '
				{
					for(i=0;i<ncores;++i)
						core_sum[i] = 0;
					x=0;
					for(i=2;i<62;++i) {
						split($i,core,"#");
						for(j=0;j<ncores;++j)
							core_sum[j]+=core[2+j];
						x+=$i;
					}
					printf ("%s %.2f", $1, x/60.0);
					for(i=0;i<ncores;++i)
						printf("#%.4f", core_sum[i]/60.0);
					printf ("\n");
				}' hour_join > srmd_hour_$hour
				echo $hour > hour_marker
				#Add a column every hour in the day bucket
				cat day_join > temp_day
				join -a 2 temp_day srmd_hour_$hour > day_join 2> /dev/null
			done #(23 -1 0)
			awk -v ncores=$n_cores '
			{
				for(i=0;i<ncores;++i)
					core_sum[i] = 0;
				x=0;
				for(i=2;i<26;++i) {
					split($i,core,"#");
					for(j=0;j<ncores;++j)
						core_sum[j]+=core[2+j];
					x+=$i;
				}
				printf ("%s %.2f", $1, x/24.0);
				for(i=0;i<ncores;++i)
					printf("#%.4f", core_sum[i]/24.0);
				printf ("\n");
			}' day_join > srmd_day_$day
			echo $day > day_marker
			cat month_join > temp_month
			join -a 2 temp_month srmd_day_$day > month_join 2> /dev/null
		done #(31 -1 0)	
		awk -v ncores=$n_cores '
		{
			for(i=0;i<ncores;++i)
				core_sum[i] = 0;
			x=0;
			for(i=2;i<33;++i) {
				split($i,core,"#");
				for(j=0;j<ncores;++j)
					core_sum[j]+=core[2+j];
				x+=$i;
			}
			printf ("%s %.2f", $1, x/31.0);
			for(i=0;i<ncores;++i)
				printf("#%.4f", core_sum[i]/31.0);
			printf ("\n");
		} ' month_join > srmd_month_$month
	done #(11 -1 0)	
done #while	
